#!/usr/bin/perl

package HTTP::Engine::Role::ResponseWriter;
use Moose::Role;

requires "finalize";

__PACKAGE__

__END__

=pod

=head1 NAME

HTTP::Engine::Role::ResponseWriter - 

=head1 SYNOPSIS

	use HTTP::Engine::Role::ResponseWriter;

=head1 DESCRIPTION

=cut


