#!/usr/bin/perl

package HTTP::Engine::Role::RequestProcessor;
use Moose::Role;

requires "handle_request";

__PACKAGE__

__END__

=pod

=head1 NAME

HTTP::Engine::Role::RequestProcessor - 

=head1 SYNOPSIS

	use HTTP::Engine::Role::RequestProcessor;

=head1 DESCRIPTION

=cut


